@@ -43,19 +43,19 @@ pub trait HierCurlBasisFnSpace: Clone + Sync + Send + std::fmt::Debug {
     fn tang_d2(&self, n: usize, p: usize) -> f64;
 }
 
-/// A utility structure used to generate and cache [BasisFn]'s during Integration
+/// A utility structure used to generate and cache [HierBasisFn]'s during Integration
 ///
 /// Three important areas of functionality are handled here:
-/// * Convert `BasisSpec`s (abstract basis function definitions on an [Elem]) into [BasisFn]'s (numerical instantiations of basis functions for integration)
+/// * Convert `BasisSpec`s (abstract basis function definitions on an [Elem]) into [HierBasisFn]'s (numerical instantiations of basis functions for integration)
 /// * Handle interpolation between parametric spaces to set up inter-layer integration
-/// * Cache computed [BasisFn]'s to avoid re-computation.
+/// * Cache computed [HierBasisFn]'s to avoid re-computation.
 ///
-pub struct BasisFnSampler<B: BasisFn> {
-    /// Maximum u-directed expansion order. [BasisFn]s Generated by this sampler will be defined up to this order in `i`
+pub struct BasisFnSampler<B: HierBasisFn> {
+    /// Maximum u-directed expansion order. [HierBasisFn]s Generated by this sampler will be defined up to this order in `i`
     pub i_max: usize,
-    /// Maximum v-directed expansion order. [BasisFn]s Generated by this sampler will be defined up to this order in `i`              
+    /// Maximum v-directed expansion order. [HierBasisFn]s Generated by this sampler will be defined up to this order in `i`              
     pub j_max: usize,
-    /// Whether the 2nd derivatives of the [BasisFn]s will be computed. If true, the endpoints [-1, +1] are also defined along both axes!                 
+    /// Whether the 2nd derivatives of the [HierBasisFn]s will be computed. If true, the endpoints [-1, +1] are also defined along both axes!                 
     pub compute_d2: bool,
     /// Gauss Legendre Quadrature points evaluated along u-direction. Defined from (-1 to +1)         
     u_points: Vec<f64>,
@@ -65,14 +65,14 @@ pub struct BasisFnSampler<B: BasisFn> {
     computed: Arc<Mutex<HashMap<BSDescription, Arc<B>>>>,
 }
 
-impl<B: BasisFn> BasisFnSampler<B> {
+impl<B: HierBasisFn> BasisFnSampler<B> {
     /// Construct a Basis Function Sampler with the following parameters:
     ///
     /// * `i_max` : maximum u-directed expansion order
     /// * `j_max` : maximum v-directed expansion order
     /// * `num_u_points` : number of Gauss-Leg-Quad points to define along the u-axis. If `None`: a default value is used
     /// * `num_v_points` : number of Gauss-Leg-Quad points to define along the v-axis. If `None`: a default value is used
-    /// * `compute_2nd_derivs`: whether or not to compute the second derivatives of the [BasisFn]s.
+    /// * `compute_2nd_derivs`: whether or not to compute the second derivatives of the [HierBasisFn]s.
     pub fn with(
         i_max: usize,
         j_max: usize,
@@ -102,7 +102,7 @@ impl<B: BasisFn> BasisFnSampler<B> {
         )
     }
 
-    /// Generate or retrieve a [BasisFn] defined over an [Elem]. Can be defined over a subset of the `Elem`.
+    /// Generate or retrieve a [HierBasisFn] defined over an [Elem]. Can be defined over a subset of the `Elem`.
     pub fn sample_basis_fn(&mut self, elem: &Elem, over_desc_elem: Option<&Elem>) -> Arc<B> {
         let desc = BSDescription::new(elem, over_desc_elem);
 
@@ -134,7 +134,7 @@ impl<B: BasisFn> BasisFnSampler<B> {
     }
 }
 
-impl<B: BasisFn> Clone for BasisFnSampler<B> {
+impl<B: HierBasisFn> Clone for BasisFnSampler<B> {
     fn clone(&self) -> Self {
         Self {
             i_max: self.i_max,
@@ -176,8 +176,8 @@ fn default_ngq(max_order: usize) -> usize {
     (2.0_f32).powi(conv_p2).round() as usize
 }
 
-/// A Trait for any Basis Function Defined over some [Elem] (and optionally sub-sampled over one of its descendant [Elem]s)
-pub trait BasisFn {
+/// A Trait for any Hierarchical Basis Function Defined over some [Elem] (and optionally sub-sampled over one of its descendant [Elem]s)
+pub trait HierBasisFn {
     /// The Shared Basis Function Constructor
     ///
     /// Basis functions must be defined over individual [Elem]s in the `Domain`, and due to the RBS structure of the `Mesh`, we must be able to sample sub-regions of Basis Functions over descendant [Elem]s
@@ -202,7 +202,7 @@ pub trait BasisFn {
 /// * `F_v(u, v, i, j) = T_i(u) * N_j(v) * J^-1_v(u, v)`
 /// * `F_w(u, v, i, j) = T_i(u) * T_j(v) * J_z(u, v)`   (Not Yet Implemented)
 ///
-/// Where the Functions N, and T are defined by the [HierCurlBasisFnSpace].
+/// Where the Functions N, and T are the Normal and Tangentially directed Function spaces defined by the [HierCurlBasisFnSpace]. This structure is Generic over any [HierCurlBasisFnSpace].
 ///
 /// The Jacobian is defined by the [Elem]'s mapping to real space (and the mapping between the [Elem]s and its descendant, in the case of sub-sampling)
 ///
@@ -348,7 +348,7 @@ impl<BSpace: HierCurlBasisFnSpace> HierCurlBasisFn<BSpace> {
     }
 }
 
-impl<BSpace: HierCurlBasisFnSpace> BasisFn for HierCurlBasisFn<BSpace> {
+impl<BSpace: HierCurlBasisFnSpace> HierBasisFn for HierCurlBasisFn<BSpace> {
     /// Create a Basis Function instance defined over some `Elem` (and optionally mapped over some descendant `Elem`)
     ///
     /// # Arguments
